pitchtools.chromatic_pitch_class_number_to_diatonic_pitch_class_number
======================================================================

.. autofunction:: abjad.tools.pitchtools.chromatic_pitch_class_number_to_diatonic_pitch_class_number.chromatic_pitch_class_number_to_diatonic_pitch_class_number
